@@ -46,7 +46,8 @@
 #include <stdlib.h>		/* getenv() */
 #include <stdio.h>
 #include <string.h>		/* strcmp() strlen() strstr() */
-#include <sys/types.h>		/* open() */
+#include <sys/types.h>		/* open() stat() */
+#include <sys/stat.h>		/* stat() */
 #include <fcntl.h>		/* open() */
 #include <unistd.h>		/* open() */
 #include <time.h>		/* ctime() */
@@ -55,9 +56,8 @@
 #include "dds_tape.h"
 #include "zf-cre-open.h"
 
-#ifndef VENDOR
-#define VENDOR HP
-#endif
+char vendor[9] = "\0\0\0\0\0\0\0\0\0" ;
+int vid; /* vendor id */
 
 /*-------------------------------------------------------------------------*/
 
@@ -68,10 +68,8 @@ static const char help_text_dds2index[] =
 "-z,--compress           filter location file through gzip\n"
 "--z,--no-compress       don't filter location file through gzip\n"
 "-f,--device F           read the archive from device F\n"
-"-b,--block-size #       set block size\n"
-#if VENDOR == HP
-"-B,--Block-size #       set block size of the device\n"
-#endif
+"-b,--block-size #       set block size (non HP/SONY)\n"
+"-B,--Block-size #       set block size (HP or SONY)\n"
 "-q,--quick              don't extract parent directories from tape\n"
 "-v,--verbose            verbose mode\n"
 "--hash-mode             hash mode\n"
@@ -99,10 +97,8 @@ static const char help_text_dds2tar[] =
 "--z,--no-compress       don't filter location file through gzip\n"
 "-f,--device F           read the archive from device F\n"
 "-o,--output F           write output to archive file\n"
-"-b,--block-size #       set block size\n"
-#if VENDOR == HP
-"-B,--Block-size #       set block size of the device\n"
-#endif
+"-b,--block-size #       set block size (non HP/SONY)\n"
+"-B,--Block-size #       set block size (HP or SONY)\n"
 "-s,--first_block #      set number of the first block\n"
 "--body                  print only the contents of the first file an quit\n"
 "-v,--verbose            verbose mode\n"
@@ -319,6 +315,26 @@ open_device(char const *pathname, int const open_mode)
 	int     i = 1;
 	char   const *p = "next try to open the tape %s\n";
 
+	{
+		int i ;
+		struct stat s ;
+		FILE *f ;
+		char cmd[100];
+		i = stat(pathname,&s);
+		if ( i < 0 ) perror("dds2tar"),exit(1);
+		sprintf(cmd,"scsi_vendor tape %d",(int)(s.st_rdev&0x7f)+1);
+		f = popen(cmd,"r");
+		fread(vendor,1,8,f);
+		fclose(f);
+		for ( i = 0 ; i < 8 ; i++ )
+			( vendor[i] < 0x20 ) && ( vendor[i] = '\0' ) ;
+		if ( !strcmp(vendor,"HP") ) vid = HP ;
+		if ( !strcmp(vendor,"SONY") ) vid = SONY ;
+		if ( !strcmp(vendor,"ARCHIVE") ) vid = ARCHIVE ;
+		if ( !strcmp(vendor,"SEGATE") ) vid = SEGATE ;
+		if ( !strcmp(vendor,"EXABYTE") ) vid = EXABYTE ;
+	}
+		
 	do {
 		if ((fd = open(pathname, open_mode)) >= 0)
 			break;
@@ -329,7 +345,7 @@ open_device(char const *pathname, int const open_mode)
 	if (fd < 0) {
 		perror("tape busy?");
 		exit(1);
-	}
+	} /* else dds_has_partitions(fd); */
 	return fd;
 }
 
@@ -355,9 +371,7 @@ main(int argc, char const *const *argv)
 #define DEVICE "/dev/rmt0"
 #endif
 
-#if VENDOR == HP
 	int	density = 0 ;
-#endif
 	int     n = 1;
 	int     l = strlen(argv[0]);
 	int     compressed_mode = T_MODE;
@@ -406,17 +420,15 @@ main(int argc, char const *const *argv)
 			p += count;
 		} else if (strprefix(&p, "--block-size ","-b ")){
 			sscanf(p, "%d%n", &tar_bs, &count);
-			tar_n = tar_bs * 512;
+			tar_n = tar_bs * 512 ;
 			buf_n = tar_n ;
 			p += count;
-#if VENDOR == HP
 		} else if (strprefix(&p, "--Block-size ","-B ")){
 			sscanf(p, "%d%n", &tar_bs, &count);
-			tar_n = tar_bs * 512;
+			tar_n = tar_bs * 512 ;
 			buf_n = tar_n ;
 			p += count;
 			density = tar_n ;
-#endif
 		} else
 			p = NULL;
 	}
@@ -489,17 +501,15 @@ main(int argc, char const *const *argv)
 		}
 		TT("-b", "--block-size") {
 			tar_bs = atoi(argv[++n]);
-			tar_n = tar_bs * 512;
+			tar_n = tar_bs * 512 ;
 			buf_n = tar_n ;
 		}
-#if VENDOR == HP
 		TT("-B", "--Block-size") {
 			tar_bs = atoi(argv[++n]);
-			tar_n = tar_bs * 512;
+			tar_n = tar_bs * 512 ;
 			buf_n = tar_n ;
 			density = tar_n ;
 		}
-#endif
 		TT("-m", "--buffer-size") {
 			fprintf(stderr,"buffer size is %d records, %d bytes\n",
 				buf_n>>9,buf_n);
@@ -723,10 +733,15 @@ main(int argc, char const *const *argv)
 		 */
 		{
 			device = open_device(device_name, O_RDONLY);
-			tar_fb = dds_getpos(device);
-			dds_read_next_block();
-			/* dds_seek(device, tar_fb); */
-			dds_bsr();
+			if ( vid == HP ){
+				tar_fb = dds_getpos(device);
+				dds_read_next_block();
+				/* dds_seek(device, tar_fb); */
+				dds_bsr();
+			} else {
+				tar_fb = dds_getpos(device);
+				cur_n = tar_n ;
+			}
 			tar_bs = cur_n >> 9;
 			if (( get_label || get_timestamp ||
 				get_date || get_filename ) &&
@@ -770,11 +785,8 @@ main(int argc, char const *const *argv)
 			return 0;
 		if (list_only != 1) {
 			device = open_device(device_name, O_RDONLY);
-#if VENDOR != HP
-			dds_set_bs(tar_n);
-#else
+
 			if ( density ) dds_set_bs(density);
-#endif
 		}
 		index_fp = zfopen(index_file, compressed_mode, "r");
 		switch (mode) {
@@ -796,18 +808,14 @@ main(int argc, char const *const *argv)
 		/*---------------------DDS2INDEX-----------------------------*/
 	} else if (pg == DDS2INDEX) {
 		device = open_device(device_name, O_RDONLY);
-#if VENDOR != HP
-		dds_set_bs(tar_n);
-#endif
+		if ( density ) dds_set_bs(density);
 		index_fp = zfopen(index_file, compressed_mode, "w");
 		dds_index();
 		close(device);
 		/*-----------------------------------------------------------*/
 	} else if ( pg == DDS_DD ) {
 		device = open_device(device_name, O_RDONLY);
-#if VENDOR != HP
-		dds_set_bs(tar_n);
-#endif
+		if ( density ) dds_set_bs(density);
 		if ( verbose ) fprintf(stderr,"dds-dd ...\n");
 		while ( dds_read_next_block() , cur_n )
 			fwrite(cur_block,1,cur_n,stdout);
@@ -815,6 +823,6 @@ main(int argc, char const *const *argv)
 		fprintf(stderr, "no program mode \n");
 		/*-----------------------------------------------------------*/
 	}
-
 	return 0;
 }
+
