@@ -18,9 +18,12 @@
 
 #include <sys/param.h>
 
-#define HP 0
-#define SEGATE 1
+#define UNKNOWN 0
+#define HP 1
+#define SONY 1
+#define SEGATE 2
 #define ARCHIVE 2
+#define EXABYTE 2
 
 extern const char dds_headline[];
 extern const char dds_index_format[];
@@ -32,6 +35,8 @@ extern const char dds_loctext[];
 extern const char dds_locline1[];
 extern const char dds_locline2[];
 extern int dds_set_bs(int);
+extern char vendor[9];
+extern int vid; /* vendor ID */
 
 /*
  * It's faster to read some records than to skip over them,
