@@ -9,6 +9,11 @@
 #include <sys/mtio.h>
 #include <string.h>
 #include <unistd.h>
+
+/*
+ * fnmatch() and FNM_LEADING_DIR
+ */
+#define _GNU_SOURCE 1
 #include <fnmatch.h>
 
 #include "dds2tar.h"
@@ -363,6 +368,7 @@ dds_cmp(char const *const *const pattern_list)
 			tar_index_file = 0;
 			tar_n = buf_n ;
 			tar_bs = buf_n >> 9 ;
+			if ( vid != HP ) dds_set_bs(tar_n);
 			continue;
 		}
 #ifdef DDS_TRACE
@@ -416,9 +422,19 @@ dds_cmp(char const *const *const pattern_list)
 			/*
 			 * Calculate the block number of the record.
 			 */
+#ifdef DDS_TRACE
+			fprintf(stderr,"file-loc(%d,%d)\n",recno,tar_fb);
+#endif
 			blkno = recno / tar_bs;
 			recno -= blkno * tar_bs;
+			if ( vid != HP ) blkno *= tar_bs ;
+#ifdef DDS_TRACE
+			fprintf(stderr,"file-loc(%d:%d,%d)\n",tar_bs,blkno,recno);
+#endif
 			blkno += tar_fb;
+#ifdef DDS_TRACE
+			fprintf(stderr,"file-loc(%d:%d,%d)\n",tar_bs,blkno,recno);
+#endif
 			if (name == NULL) {	/* calculate only once */
 				if ( strlen(cur_line) >= (66) ) {
 					name = cur_line + (65);
